@@ -8,7 +8,7 @@ import aiohttp
 from mcsniperpy.util import announce, request_manager
 from mcsniperpy.util import utils as util
 from mcsniperpy.util.classes.config import BackConfig, Config, populate_configs
-from mcsniperpy.util.name_system import api_timing, namemc_timing, teun_timing, coolkidmacho_timing
+from mcsniperpy.util.name_system import api_timing, namemc_timing, teun_timing, coolkidmacho_timing, peet_timing
 
 
 class Sniper:
@@ -180,7 +180,8 @@ class Sniper:
             "teun": teun_timing,
             "ckm": coolkidmacho_timing,
             "coolkidmacho": coolkidmacho_timing,
-        }.get(self.timing_system, "ckm")(target, self.session)
+            "peet": peet_timing,
+        }.get(self.timing_system, coolkidmacho_timing)(target, self.session)
 
         await self.snipe(droptime, target, offset)
 
@@ -254,6 +255,9 @@ class Sniper:
                     f"success{self.color.white}]{self.color.reset} "
                     f"sniped {target} onto {success_acc.email}"
                 )
+                self.log.info(
+                    f"If you like this sniper, please consider donating at {self.color.l_green}https://mcsniperpy.com/donate{self.color.reset} :)"
+                )
                 if self.do_announce:
                     await announce.announce(
                         username=target,
